@@ -5,15 +5,15 @@
     SPDX-License-Identifier: MIT
 */
 
-#ifndef   netwm_h
-#define   netwm_h
+#ifndef netwm_h
+#define netwm_h
 
-#include <kwindowsystem_export.h>
 #include <QSize>
 #include <config-kwindowsystem.h>
+#include <kwindowsystem_export.h>
 #if KWINDOWSYSTEM_HAVE_X11
-#include <xcb/xcb.h>
 #include <vector>
+#include <xcb/xcb.h>
 
 #include "netwm_def.h"
 
@@ -22,7 +22,8 @@
 // forward declaration
 struct NETRootInfoPrivate;
 struct NETWinInfoPrivate;
-template <class Z> class NETRArray;
+template<class Z>
+class NETRArray;
 
 /**
    Common API for root window properties/protocols.
@@ -43,9 +44,14 @@ public:
         Indexes for the properties array.
     **/
     // update also NETRootInfoPrivate::properties[] size when extending this
-    enum { PROTOCOLS, WINDOW_TYPES, STATES, PROTOCOLS2, ACTIONS,
-           PROPERTIES_SIZE
-         };
+    enum {
+        PROTOCOLS,
+        WINDOW_TYPES,
+        STATES,
+        PROTOCOLS2,
+        ACTIONS,
+        PROPERTIES_SIZE,
+    };
 
     /**
        Window Managers should use this constructor to create a NETRootInfo object,
@@ -78,10 +84,16 @@ public:
 
        @param doActivate true to activate the window
     **/
-    NETRootInfo(xcb_connection_t *connection, xcb_window_t supportWindow, const char *wmName,
-                NET::Properties properties, NET::WindowTypes windowTypes, NET::States states,
-                NET::Properties2 properties2, NET::Actions actions,
-                int screen = -1, bool doActivate = true);
+    NETRootInfo(xcb_connection_t *connection,
+                xcb_window_t supportWindow,
+                const char *wmName,
+                NET::Properties properties,
+                NET::WindowTypes windowTypes,
+                NET::States states,
+                NET::Properties2 properties2,
+                NET::Actions actions,
+                int screen = -1,
+                bool doActivate = true);
 
     /**
        Clients should use this constructor to create a NETRootInfo object, which
@@ -103,9 +115,11 @@ public:
        @param doActivate true to call activate() to do an initial data read/update
        of the query information.
     **/
-    NETRootInfo(xcb_connection_t *connection, NET::Properties properties, NET::Properties2 properties2 = NET::Properties2(),
-                int screen = -1, bool doActivate = true);
-
+    NETRootInfo(xcb_connection_t *connection,
+                NET::Properties properties,
+                NET::Properties2 properties2 = NET::Properties2(),
+                int screen = -1,
+                bool doActivate = true);
 
     /**
        Creates a shared copy of the specified NETRootInfo object.
@@ -559,8 +573,7 @@ public:
           caused the request
        @param active_window active window of the requesting application, if any
     **/
-    void setActiveWindow(xcb_window_t window, NET::RequestSource src,
-                         xcb_timestamp_t timestamp, xcb_window_t active_window);
+    void setActiveWindow(xcb_window_t window, NET::RequestSource src, xcb_timestamp_t timestamp, xcb_window_t active_window);
 
     /**
        Sets the active (focused) window the specified window. This should
@@ -592,8 +605,7 @@ public:
        Sets the desktop layout. This is set by the pager. When setting, the pager must
        own the _NET_DESKTOP_LAYOUT_Sn manager selection. See _NET_DESKTOP_LAYOUT for details.
     **/
-    void setDesktopLayout(NET::Orientation orientation, int columns, int rows,
-                          NET::DesktopLayoutCorner corner);
+    void setDesktopLayout(NET::Orientation orientation, int columns, int rows, NET::DesktopLayoutCorner corner);
 
     /**
      * Sets the _NET_SHOWING_DESKTOP status (whether desktop is being shown).
@@ -634,8 +646,7 @@ public:
        @param direction One of NET::Direction (see base class documentation for
        a description of the different directions).
     **/
-    void moveResizeRequest(xcb_window_t window, int x_root, int y_root,
-                           Direction direction);
+    void moveResizeRequest(xcb_window_t window, int x_root, int y_root, Direction direction);
 
     /**
        Clients (such as pagers/taskbars) that wish to move/resize a window
@@ -652,6 +663,19 @@ public:
     **/
     void moveResizeWindowRequest(xcb_window_t window, int flags, int x, int y, int width, int height);
 
+    /**
+       Clients that wish to show the window menu using WM2GTKShowWindowMenu
+       (_GTK_SHOW_WINDOW_MENU) should call this function.
+       This will send a request to the Window Manager. See _GTK_SHOW_WINDOW_MENU
+       description for details.
+
+       @param window The client window that would be resized/moved.
+       @param device_id GTK device id
+       @param x Requested X position for the menu relative to the root window
+       @param y Requested Y position for the menu relative to the root window
+    **/
+    void showWindowMenuRequest(xcb_window_t window, int device_id, int x_root, int y_root);
+
     /**
        Sends the _NET_RESTACK_WINDOW request.
     **/
@@ -663,25 +687,6 @@ public:
     */
     void sendPing(xcb_window_t window, xcb_timestamp_t timestamp);
 
-#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-       This function takes the passed XEvent and returns an OR'ed list of
-       NETRootInfo properties that have changed in the properties argument.
-       The new information will be read immediately by the class.
-       The elements of the properties argument are as they would be passed
-       to the constructor, if the array is not large enough,
-       changed properties that don't fit in it won't be listed there
-       (they'll be updated in the class though).
-
-       @param event the event
-       @param properties properties that changed
-       @param properties_size size of the passed properties array
-       @deprecated since 5.0 use event(xcb_generic_event_t*, NET::Properties*, NET::Properties2*)
-
-    **/
-    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use NETRootInfo::event(xcb_generic_event_t*, NET::Properties*, NET::Properties2*)")
-    void event(xcb_generic_event_t *event, unsigned long *properties, int properties_size);
-#endif
     /**
      * This function takes the passed xcb_generic_event_t and returns the updated properties in the passed in arguments.
      *
@@ -810,8 +815,7 @@ protected:
        @param direction One of NET::Direction (see base class documentation for
        a description of the different directions).
     **/
-    virtual void moveResize(xcb_window_t window, int x_root, int y_root,
-                            unsigned long direction)
+    virtual void moveResize(xcb_window_t window, int x_root, int y_root, unsigned long direction)
     {
         Q_UNUSED(window);
         Q_UNUSED(x_root);
@@ -840,8 +844,7 @@ protected:
        @param timestamp the timestamp of the user action causing this request
        @param active_window active window of the requesting application, if any
     **/
-    virtual void changeActiveWindow(xcb_window_t window, NET::RequestSource src,
-                                    xcb_timestamp_t timestamp, xcb_window_t active_window)
+    virtual void changeActiveWindow(xcb_window_t window, NET::RequestSource src, xcb_timestamp_t timestamp, xcb_window_t active_window)
     {
         Q_UNUSED(window);
         Q_UNUSED(src);
@@ -882,8 +885,7 @@ protected:
        @param detail restack detail
        @param timestamp the timestamp of the request
     **/
-    virtual void restackWindow(xcb_window_t window, RequestSource source,
-                               xcb_window_t above, int detail, xcb_timestamp_t timestamp)
+    virtual void restackWindow(xcb_window_t window, RequestSource source, xcb_window_t above, int detail, xcb_timestamp_t timestamp)
     {
         Q_UNUSED(window);
         Q_UNUSED(source);
@@ -904,6 +906,23 @@ protected:
         Q_UNUSED(showing);
     }
 
+    /**
+       A Window Manager should subclass NETRootInfo and reimplement this function
+       when it wants to know when a Client made a request to show a window menu.
+
+       @param window The window that wants to move/resize
+       @param device_id GTK device id.
+       @param x_root X position of the cursor relative to the root window.
+       @param y_root Y position of the cursor relative to the root window.
+    **/
+    virtual void showWindowMenu(xcb_window_t window, int device_id, int x_root, int y_root)
+    {
+        Q_UNUSED(window);
+        Q_UNUSED(device_id);
+        Q_UNUSED(x_root);
+        Q_UNUSED(y_root);
+    }
+
 private:
     void update(NET::Properties properties, NET::Properties2 properties2);
     void setSupported();
@@ -915,6 +934,7 @@ protected:
     binary compatibility. Unused in this class.
     */
     virtual void virtual_hook(int id, void *data);
+
 private:
     NETRootInfoPrivate *p; // krazy:exclude=dpointer (implicitly shared)
 };
@@ -939,9 +959,11 @@ public:
         Indexes for the properties array.
     **/
     // update also NETWinInfoPrivate::properties[] size when extending this
-    enum { PROTOCOLS, PROTOCOLS2,
-           PROPERTIES_SIZE
-         };
+    enum {
+        PROTOCOLS,
+        PROTOCOLS2,
+        PROPERTIES_SIZE,
+    };
     /**
        Create a NETWinInfo object, which will be used to set/read/change
        information stored on an application window.
@@ -959,22 +981,13 @@ public:
        @param role Select the application role.  If this argument is omitted,
        the role will default to Client.
     **/
-    NETWinInfo(xcb_connection_t *connection, xcb_window_t window, xcb_window_t rootWindow,
-               NET::Properties properties, NET::Properties2 properties2,
+    NETWinInfo(xcb_connection_t *connection,
+               xcb_window_t window,
+               xcb_window_t rootWindow,
+               NET::Properties properties,
+               NET::Properties2 properties2,
                Role role = Client);
 
-#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-        This constructor differs from the above one only in the way it accepts
-        the list of properties the client is interested in.
-        @deprecated since 5.0 use above ctor
-    **/
-    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use NETWinInfo(xcb_connection_t *, xcb_window_t, xcb_window_t, NET::Properties, NET::Properties2, Role")
-    NETWinInfo(xcb_connection_t *connection, xcb_window_t window,
-               xcb_window_t rootWindow, NET::Properties properties,
-               Role role = Client);
-#endif
-
     /**
        Creates a shared copy of the specified NETWinInfo object.
 
@@ -1353,11 +1366,19 @@ public:
      * Sets opacity (0 = transparent, 0xffffffff = opaque ) on the window.
      */
     void setOpacity(unsigned long opacity);
+    /**
+     * Sets opacity (0 = transparent, 1 = opaque) on the window.
+     */
+    void setOpacityF(qreal opacity);
 
     /**
      * Returns the opacity of the window.
      */
     unsigned long opacity() const;
+    /**
+     * Returns the opacity of the window.
+     */
+    qreal opacityF() const;
 
     /**
      * Sets actions that the window manager allows for the window.
@@ -1518,24 +1539,6 @@ public:
     **/
     NETFullscreenMonitors fullscreenMonitors() const;
 
-#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-       This function takes the passed XEvent and returns an OR'ed list of
-       NETWinInfo properties that have changed in the properties argument.
-       The new information will be read immediately by the class.
-       The elements of the properties argument are as they would be passed
-       to the constructor, if the array is not large enough,
-       changed properties that don't fit in it won't be listed there
-       (they'll be updated in the class though).
-
-       @param event the event
-       @param properties properties that changed
-       @param properties_size size of the passed properties array
-       @deprecated since 5.0 use event(xcb_generic_event_t*, NET::Properties*, NET::Properties2*)
-    **/
-    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use NETWinInfo::event(xcb_generic_event_t*, NET::Properties*, NET::Properties2*)")
-    void event(xcb_generic_event_t *event, unsigned long *properties, int properties_size);
-#endif
     /**
      * This function takes the passed in xcb_generic_event_t and returns the updated properties
      * in the passed in arguments.
@@ -1606,6 +1609,12 @@ public:
      **/
     const char *desktopFileName() const;
 
+    /**
+     * @returns The GTK application id of the window if present.
+     * @since 5.91
+     **/
+    const char *gtkApplicationId() const;
+
     /**
      * Sets the @p name as the D-BUS service name for the application menu.
      * @since 5.69
@@ -1690,6 +1699,7 @@ protected:
     binary compatibility. Unused in this class.
     */
     virtual void virtual_hook(int id, void *data);
+
 private:
     NETWinInfoPrivate *p; // krazy:exclude=dpointer (implicitly shared)
 };
